@@ -35,11 +35,11 @@ extern "C" {
  *
  * Library version string
  */
-#define LIBFDISK_VERSION   "2.38.1"
+#define LIBFDISK_VERSION   "2.41.3"
 
 #define LIBFDISK_MAJOR_VERSION   2
-#define LIBFDISK_MINOR_VERSION   38
-#define LIBFDISK_PATCH_VERSION   1
+#define LIBFDISK_MINOR_VERSION   41
+#define LIBFDISK_PATCH_VERSION   3
 
 /**
  * fdisk_context:
@@ -540,6 +540,9 @@ extern int fdisk_reorder_partitions(struct fdisk_context *cxt);
 
 extern int fdisk_partition_has_wipe(struct fdisk_context *cxt, struct fdisk_partition *pa);
 
+extern int fdisk_partition_get_max_size(struct fdisk_context *cxt, size_t n,
+					fdisk_sector_t *maxsz);
+
 
 /* table.c */
 extern struct fdisk_table *fdisk_new_table(void);
@@ -869,6 +872,9 @@ int fdisk_ask_yesno(struct fdisk_context *cxt,
 		     int *result);
 int fdisk_ask_yesno_get_result(struct fdisk_ask *ask);
 int fdisk_ask_yesno_set_result(struct fdisk_ask *ask, int result);
+
+int fdisk_ask_menu(struct fdisk_context *cxt, char *query, int *result, int dflt, ...);
+
 int fdisk_ask_menu_get_default(struct fdisk_ask *ask);
 int fdisk_ask_menu_set_result(struct fdisk_ask *ask, int key);
 int fdisk_ask_menu_get_result(struct fdisk_ask *ask, int *key);
